# pylint: disable=C0114,C0116

def test_animate_subcommand(cli_runner, image_file):
    img_path1 = image_file("sample.png")
    img_path2 = image_file("sample.png")
    ret = cli_runner('animate', str(img_path1), str(img_path2))
    assert ret.returncode == 0



# pylint: disable=C0114,C0116

import platform
import sys

from fotolab import __version__


def test_env_output(cli_runner):
    ret = cli_runner("env")

    actual_sys_version = sys.version.replace("\n", "")
    actual_platform = platform.platform()

    expected_output = (
        f"fotolab: {__version__}\n"
        f"python: {actual_sys_version}\n"
        f"platform: {actual_platform}\n"
    )

    assert ret.stdout == expected_output
    assert ret.stderr == ""
    assert ret.returncode == 0



# pylint: disable=C0114,C0116

def test_contrast_subcommand(cli_runner, image_file):
    img_path = image_file("sample.png")
    ret = cli_runner('contrast', str(img_path))
    assert ret.returncode == 0
